==> oci-java-sdk-shaded-full-3.48.0-sources.jar: com/oracle/bmc/opsi/model/NewsFrequency.java <==
/**
 * Copyright (c) 2016, 2024, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
package com.oracle.bmc.opsi.model;

/**
 * Frequency in which the news report will be sent. WEEKLY: Receive an OPSI news report every week.
 */
@jakarta.annotation.Generated(value = "OracleSDKGenerator", comments = "API Version: 20200630")
public enum NewsFrequency implements com.oracle.bmc.http.internal.BmcEnum {
    Weekly("WEEKLY"),

    /**
     * This value is used if a service returns a value for this enum that is not recognized by this
     * version of the SDK.
     */
    UnknownEnumValue(null);

    private static final org.slf4j.Logger LOG =
            org.slf4j.LoggerFactory.getLogger(NewsFrequency.class);

    private final String value;
    private static java.util.Map<String, NewsFrequency> map;

    static {
        map = new java.util.HashMap<>();
        for (NewsFrequency v : NewsFrequency.values()) {
            if (v != UnknownEnumValue) {
                map.put(v.getValue(), v);
            }
        }
    }

    NewsFrequency(String value) {
        this.value = value;
    }

    @com.fasterxml.jackson.annotation.JsonValue
    public String getValue() {
        return value;
    }

    @com.fasterxml.jackson.annotation.JsonCreator
    public static NewsFrequency create(String key) {
        if (map.containsKey(key)) {
            return map.get(key);
        }
        LOG.warn(
                "Received unknown value '{}' for enum 'NewsFrequency', returning UnknownEnumValue",
                key);
        return UnknownEnumValue;
    }
}

==> oci-java-sdk-shaded-full-3.63.1-sources.jar: com/oracle/bmc/opsi/model/NewsFrequency.java <==
/**
 * Copyright (c) 2016, 2025, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
package com.oracle.bmc.opsi.model;

/**
 * Frequency in which the news report will be sent. WEEKLY: Receive an OPSI news report every week.
 * DAILY: Receive an OPSI news report every day. HOURLY: Receive an actionable insights report every
 * hour if there are significant changes to the customer's resources.
 */
@jakarta.annotation.Generated(value = "OracleSDKGenerator", comments = "API Version: 20200630")
public enum NewsFrequency implements com.oracle.bmc.http.internal.BmcEnum {
    Weekly("WEEKLY"),
    Daily("DAILY"),
    Hourly("HOURLY"),

    /**
     * This value is used if a service returns a value for this enum that is not recognized by this
     * version of the SDK.
     */
    UnknownEnumValue(null);

    private static final org.slf4j.Logger LOG =
            org.slf4j.LoggerFactory.getLogger(NewsFrequency.class);

    private final String value;
    private static java.util.Map<String, NewsFrequency> map;

    static {
        map = new java.util.HashMap<>();
        for (NewsFrequency v : NewsFrequency.values()) {
            if (v != UnknownEnumValue) {
                map.put(v.getValue(), v);
            }
        }
    }

    NewsFrequency(String value) {
        this.value = value;
    }

    @com.fasterxml.jackson.annotation.JsonValue
    public String getValue() {
        return value;
    }

    @com.fasterxml.jackson.annotation.JsonCreator
    public static NewsFrequency create(String key) {
        if (map.containsKey(key)) {
            return map.get(key);
        }
        LOG.warn(
                "Received unknown value '{}' for enum 'NewsFrequency', returning UnknownEnumValue",
                key);
        return UnknownEnumValue;
    }
}
